apply_bin

Function apply_bin 

fn apply_bin(op: BinOpKind, a: Num, b: Num) -> Option<Num>
Applies a binary operator to two folded numeric values, carrying the result width so narrow operands produce in-range results.